import React from 'react';
import PropTypes from 'prop-types';
import { TableRequestMoveRowHandler } from './Table';
import { ComponentProps } from '../utils/types';
/** @public */
type RowActionPrimaryClickHandler = (event: React.MouseEvent, data?: any) => void;
/** @public */
type RowActionSecondaryClickHandler = (event: React.MouseEvent, data?: any) => void;
/** @public */
type RowClickHandler = (event: React.MouseEvent<HTMLTableRowElement> | React.KeyboardEvent<HTMLTableRowElement>, data?: any) => void;
type RowRequestMoveRowHandler = TableRequestMoveRowHandler;
type RowExpansionHandler = (event: React.MouseEvent<HTMLButtonElement> | React.KeyboardEvent<HTMLButtonElement>, data?: any) => void;
/** @public */
type RowRequestExpansionHandler = (event: React.MouseEvent<HTMLButtonElement> | React.KeyboardEvent<HTMLButtonElement>, data?: any) => void;
/** @public */
type RowRequestToggleHandler = (event: React.MouseEvent<HTMLButtonElement | HTMLAnchorElement>, data?: any) => void;
interface RowPropsBase {
    /** @private. Generally passed by Table rather than added directly. */
    activeElementId?: string;
    /**
     * Adds primary actions. For best results, use an icon-only button style.
     * The `onClick` handler of each action is passed the event and the `data` prop of this row.
     */
    actionPrimary?: React.ReactElement;
    /**
     * Adds a secondary actions dropdown menu. This prop must be a `Menu`.
     * The `onClick` handler of each action is passed the event and the `data` prop of this row.
     */
    actionsSecondary?: React.ReactElement;
    /**
     * Must be `Table.Cell`.
     */
    children?: React.ReactNode;
    /** This data is returned with the onClick and toggle events as the second argument. */
    data?: any;
    /** Indicates whether the row selection is disabled. */
    disabled?: boolean;
    /** @private. Generally passed by Table rather than added directly. */
    isDraggable?: boolean;
    /** @private. Generally passed by Table rather than added directly. */
    dragId?: string | number;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLTableRowElement>;
    /** @private. */
    expandable?: boolean;
    /**
     * Allows row expansion to be controlled programmatically if the `rowExpansion` prop is set to `controlled` in `Table`.
     */
    expanded?: boolean;
    /**
     * @private. Identifies the unique id (or ids) for an expanded row (or rows). In expandable rows `ExpansionRowIcon` uses `expansionRowId` for accessibility aria attributes.
     */
    expansionRowIds?: string;
    /**
     * An optional row that is displayed when this row is expanded, or an array of rows.
     */
    expansionRow?: React.ReactElement | React.ReactElement[];
    /** @private. Indicates whether the table has an actions column. */
    actions?: boolean;
    /** @private. Generally passed by `Table` rather than added directly. */
    index?: number;
    /** @private. Generally passed by `Table` rather than added directly. */
    movableColumns?: boolean;
    /** Providing an `onClick` handler enables focus, hover, and related styles. */
    onClick?: RowClickHandler;
    /**
     * An event handler that triggers when the row expansion element is selected.
     */
    onExpansion?: RowExpansionHandler;
    /** @private. This is passed through and works as expected. */
    onKeyDown?: React.KeyboardEventHandler<HTMLTableRowElement>;
    /** @private. Generally passed by `Table` rather than added directly. */
    onRequestMoveRow?: RowRequestMoveRowHandler;
    /**
     * An event handler for toggle of the row. resize of columns. The function is passed the event and the `data` prop for this row.
     */
    onRequestToggle?: RowRequestToggleHandler;
    /**
     * @private. Generally passed by Table rather than added directly. Indicates the column to use as the primary label for each row.
     */
    primaryColumnIndex?: number;
    /**
     * Indicates the row's label when selected or unselected.
     */
    rowScreenReaderText?: string;
    /**
     * When an `onRequestToggle` handler is defined, this prop determines the appearance
     * of the toggle.
     */
    selected?: boolean;
    /** @private. */
    stripe?: 'odd' | 'even' | 'none';
}
type RowProps = ComponentProps<RowPropsBase, 'tr'>;
declare function Row(props: RowProps): React.JSX.Element;
declare namespace Row {
    var propTypes: {
        /** @private. Generally passed by Table rather than added directly. */
        activeElementId: PropTypes.Requireable<string>;
        actionPrimary: PropTypes.Requireable<PropTypes.ReactElementLike>;
        actionsSecondary: PropTypes.Requireable<PropTypes.ReactElementLike>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        data: PropTypes.Requireable<any>;
        disabled: PropTypes.Requireable<boolean>;
        /** @private. Generally passed by Table rather than added directly. */
        isDraggable: PropTypes.Requireable<boolean>;
        /** @private. Generally passed by Table rather than added directly. */
        dragId: PropTypes.Requireable<NonNullable<string | number | null | undefined>>;
        elementRef: PropTypes.Requireable<object>;
        /** @private. */
        expandable: PropTypes.Requireable<boolean>;
        expanded: PropTypes.Requireable<boolean>;
        /** @private. Identifies the unique id (or ids) for an expanded row (or rows). In expandable rows `ExpansionRowIcon` uses `expansionRowId` for accessibility aria attributes. */
        expansionRowIds: PropTypes.Requireable<string>;
        expansionRow: PropTypes.Requireable<NonNullable<PropTypes.ReactElementLike | (PropTypes.ReactElementLike | null | undefined)[] | null | undefined>>;
        /** @private. Indicates whether the table has an actions column. */
        actions: PropTypes.Requireable<boolean>;
        /** @private. Generally passed by `Table` rather than added directly. */
        index: PropTypes.Requireable<number>;
        /** @private. Generally passed by `Table` rather than added directly. */
        movableColumns: PropTypes.Requireable<boolean>;
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        onExpansion: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. This is passed through and works as expected. */
        onKeyDown: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. Generally passed by `Table` rather than added directly. */
        onRequestMoveRow: PropTypes.Requireable<(...args: any[]) => any>;
        onRequestToggle: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. Generally passed by `Table` rather than added directly. */
        primaryColumnIndex: PropTypes.Requireable<number>;
        rowScreenReaderText: PropTypes.Requireable<string>;
        selected: PropTypes.Requireable<boolean>;
        /** @private. */
        stripe: PropTypes.Requireable<string>;
    };
    var splunkUiType: string;
}
export default Row;
export { RowActionPrimaryClickHandler, RowActionSecondaryClickHandler, RowClickHandler, RowRequestExpansionHandler, RowRequestMoveRowHandler, RowRequestToggleHandler, RowExpansionHandler, };
