import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
/** @public */
type TooltipPossibleOpenReason = 'focusToggle' | 'mouseEnterPopover' | 'mouseEnterToggle' | 'mouseEnterHitArea';
/** @public */
type TooltipPossibleCloseReason = 'blurToggle' | 'clickAway' | 'escapeKey' | 'mouseLeaveHitArea' | 'mouseLeavePopover' | 'mouseLeaveToggle' | 'mouseStopHitArea' | 'offScreen' | 'tabKey' | 'toggleClick';
/** @public */
type TooltipRequestCloseHandler = (event: React.FocusEvent<HTMLSpanElement> | React.MouseEvent | MouseEvent | null, data: {
    reason: TooltipPossibleCloseReason;
}) => void;
/** @public */
type TooltipRequestOpenHandler = (event: React.FocusEvent<HTMLSpanElement> | MouseEvent, data: {
    reason: TooltipPossibleOpenReason;
}) => void;
interface AnchorProps {
    onFocus: React.FocusEventHandler<HTMLElement>;
    onBlur: React.FocusEventHandler<HTMLElement>;
    onClick: React.MouseEventHandler<HTMLElement>;
    elementRef: React.Ref<never>;
    ['data-test']: 'toggle';
    describedBy?: string;
    ['aria-describedby']?: string;
    labelledBy?: string;
    ['aria-labelledby']?: string;
}
interface TooltipPropsBase {
    /** @private */
    appearance?: 'normal' | 'inverted' | 'none';
    /**
     * Provide a node to replace the default question mark.
     * For accessibility, ensure that the child can take focus, and that it
     * accepts a `describedBy` string prop which it places as `aria-describedby`
     * on the appropriate internal element.
     */
    children?: React.ReactNode;
    /**
     * @private
     *
     */
    closeWhen?: 'default' | 'notOnClick';
    /**
     * The content of the tooltip. If the content is falsy and the `open` prop
     * is uncontrolled, the tooltip doesn't display.
     */
    content?: React.ReactNode;
    /**
     * Tooltips can define the primary label for controls, for example buttons with only an icon,
     * or they can provide an auxiliary description to supplement a control's primary label.
     * This relationship is conveyed to assistive technologies with either the
     * `aria-labelledby` or `aria-describedby` properties.
     * By default, tooltips are a description for their control and use `aria-describedby`.
     * Set `contentRelationship` to `label` when the Tooltip's content is a primary label for the control.
     */
    contentRelationship?: 'description' | 'label';
    /**
     * Milliseconds to wait before the tooltip closes.
     */
    closeDelay?: number;
    /**
     * Milliseconds to wait before the tooltip opens.
     */
    openDelay?: 'primary' | 'secondary' | number;
    /**
     * The default placement of the `Tooltip`. It might render in a different location if there is
     * not enough space in the default direction.
     */
    defaultPlacement?: 'above' | 'below' | 'left' | 'right';
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLElement>;
    /**
     * Set inline to `false` when adding a tooltip to a block element.
     */
    inline?: boolean;
    /**
     * Callback function fired when the popover is requested to be closed.
     *
     * @param {event} event Can be `null` depending on the reason the tooltip is closing.
     * @param {object} data
     * @param {string} data.reason The reason for the close request.
     */
    onRequestClose?: TooltipRequestCloseHandler;
    /**
     * Callback function fired when the popover is requested to be opened.
     *
     * @param {event} event
     * @param {object} data
     * @param {string} data.reason The reason for the open request.
     */
    onRequestOpen?: TooltipRequestOpenHandler;
    /**
     * Whether or not the tooltip is shown. Setting this value makes the prop controlled.
     * The onRequestClose and onRequestOpen callbacks are usually used.
     */
    open?: boolean;
    /**
     * A function for rendering the element that the tooltip is bound to. If both `renderAnchor` and
     * `children` are passed, `children` will be ignored. The function gets as input props object
     * for the anchor, which contains the necessary event listeners and aria attributes. By default
     * or if `contentRelationship` is passed as `description`, the props object contains keys
     * `aria-describedby` and `describedBy`, but if `contentRelationship` is passed as `label`,
     * `aria-labelledby` and `labelledBy` will be passed instead.
     *
     * @param {object} props
     * @param {function} props.onFocus
     * @param {function} props.onBlur
     * @param {function} props.onClick
     * @param {string} props['aria-describedby']
     * @param {string} props.describedBy
     * @param {string} props['aria-labelledby']
     * @param {string} props.labelledBy
     * @param {"toggle"} props.['data-test']
     * @param {function} props.elementRef
     */
    renderAnchor?: (props: AnchorProps) => React.ReactNode;
}
type TooltipProps = ComponentProps<TooltipPropsBase, 'span'>;
/**
 * The Tooltip component wraps arbitrary content to be displayed when the target element is hovered
 * or focused.
 */
declare function Tooltip({ appearance, children, closeDelay, closeWhen, content, contentRelationship, defaultPlacement, elementRef, inline, onRequestClose, onRequestOpen, open: openProp, openDelay, renderAnchor, ...otherProps }: TooltipProps): React.JSX.Element;
declare namespace Tooltip {
    var propTypes: {
        /** @private */
        appearance: PropTypes.Requireable<string>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        closeDelay: PropTypes.Requireable<number>;
        /** @private */
        closeWhen: PropTypes.Requireable<string>;
        content: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        contentRelationship: PropTypes.Requireable<string>;
        defaultPlacement: PropTypes.Requireable<string>;
        elementRef: PropTypes.Requireable<object>;
        inline: PropTypes.Requireable<boolean>;
        onRequestClose: PropTypes.Requireable<(...args: any[]) => any>;
        onRequestOpen: PropTypes.Requireable<(...args: any[]) => any>;
        open: PropTypes.Requireable<boolean>;
        openDelay: PropTypes.Requireable<NonNullable<string | number | null | undefined>>;
        renderAnchor: PropTypes.Requireable<(...args: any[]) => any>;
    };
    var possibleOpenReasons: TooltipPossibleOpenReason[];
    var possibleCloseReasons: TooltipPossibleCloseReason[];
}
export default Tooltip;
export { TooltipRequestCloseHandler, TooltipRequestOpenHandler };
export type { AnchorProps, TooltipPropsBase, TooltipPossibleOpenReason, TooltipPossibleCloseReason, };
